Struct rtp::codecs::h265::H265NALUHeader[][src]

pub struct H265NALUHeader(pub u16);
H265NALUHeader is a H265 NAL Unit Header https://datatracker.ietf.org/doc/html/rfc7798#section-1.1.4 +—————+—————+ |0|1|2|3|4|5|6|7|0|1|2|3|4|5|6|7| +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ |F| Type | layer_id | tid | +———––+—————–+

Tuple Fields

0: u16

Implementations

f is the forbidden bit, should always be 0.

nalu_type of NAL Unit.

is_type_vcl_unit returns whether or not the NAL Unit type is a VCL NAL unit.

layer_id should always be 0 in non-3D HEVC context.

tid is the temporal identifier of the NAL unit +1.

is_aggregation_packet returns whether or not the packet is an Aggregation packet.

is_fragmentation_unit returns whether or not the packet is a Fragmentation Unit packet.

is_paci_packet returns whether or not the packet is a PACI packet.