Trait rtp::packetizer::Marshaller [−][src]
pub trait Marshaller {
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error>
where
Self: Sized;
fn marshal_size(&self) -> usize;
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>;
fn marshal(&self) -> Result<Bytes, Error> { ... }
}Required methods
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error> where
Self: Sized, [src]
Self: Sized,
fn marshal_size(&self) -> usize[src]
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>[src]
Provided methods
Loading content...Implementors
impl Marshaller for AbsSendTimeExtension[src]
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error>[src]
Unmarshal parses the passed byte slice and stores the result in the members.
fn marshal_size(&self) -> usize[src]
MarshalSize returns the size of the AbsSendTimeExtension once marshaled.
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>[src]
MarshalTo serializes the members to buffer.
impl Marshaller for AudioLevelExtension[src]
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error>[src]
Unmarshal parses the passed byte slice and stores the result in the members
fn marshal_size(&self) -> usize[src]
MarshalSize returns the size of the AudioLevelExtension once marshaled.
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>[src]
MarshalTo serializes the members to buffer
impl Marshaller for TransportCcExtension[src]
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error>[src]
Unmarshal parses the passed byte slice and stores the result in the members
fn marshal_size(&self) -> usize[src]
MarshalSize returns the size of the TransportCcExtension once marshaled.
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>[src]
Marshal serializes the members to buffer
impl Marshaller for Header[src]
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error>[src]
Unmarshal parses the passed byte slice and stores the result in the Header this method is called upon
fn marshal_size(&self) -> usize[src]
MarshalSize returns the size of the packet once marshaled.
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>[src]
Marshal serializes the header and writes to the buffer.
impl Marshaller for Packet[src]
fn unmarshal(raw_packet: &Bytes) -> Result<Self, Error>[src]
Unmarshal parses the passed byte slice and stores the result in the Header this method is called upon
fn marshal_size(&self) -> usize[src]
MarshalSize returns the size of the packet once marshaled.
fn marshal_to(&self, buf: &mut BytesMut) -> Result<usize, Error>[src]
MarshalTo serializes the packet and writes to the buffer.